@@ -63,23 +63,23 @@ class Client(object):
         return self.workspace.file.get_content(absolute_path)
 
     # wrappers
-    def _get_csv_wrapper(self, absolute_path):
-        return self.workspace.file.get_csv_wrapper(absolute_path)
-    def _get_json_wrapper(self, absolute_path):
-        return self.workspace.file.get_json_wrapper(absolute_path)
+    def _get_csv_wrapper(self, absolute_path, encoding='utf-8'):
+        return self.workspace.file.get_csv_wrapper(absolute_path, encoding='utf-8')
+    def _get_json_wrapper(self, absolute_path, encoding='utf-8'):
+        return self.workspace.file.get_json_wrapper(absolute_path, encoding='utf-8')
     def _get_image_wrapper(self, absolute_path):
         return self.workspace.file.get_image_wrapper(absolute_path)
     # csv
-    def get_csv(self, absolute_path):
-        return self._get_csv_wrapper(absolute_path).to_list()
-    def get_pandas_csv(self, absolute_path, *args, **kwargs):
-        return self._get_csv_wrapper(absolute_path).to_pandas(*args, **kwargs)
+    def get_csv(self, absolute_path, encoding='utf-8'):
+        return self._get_csv_wrapper(absolute_path, encoding).to_list()
+    def get_pandas_csv(self, absolute_path, encoding='utf-8', *args, **kwargs):
+        return self._get_csv_wrapper(absolute_path, encoding).to_pandas(*args, **kwargs)
 
     # json
-    def get_json(self, absolute_path):
-        return self._get_json_wrapper(absolute_path).to_json()
-    def get_pandas_json(self, absolute_path, *args, **kwargs):
-        return self._get_json_wrapper(absolute_path).to_pandas(*args, **kwargs)
+    def get_json(self, absolute_path, encoding='utf-8'):
+        return self._get_json_wrapper(absolute_path, encoding).to_json()
+    def get_pandas_json(self, absolute_path, encoding='utf-8', *args, **kwargs):
+        return self._get_json_wrapper(absolute_path, encoding).to_pandas(*args, **kwargs)
     
     # image
     def get_pil_image(self, absolute_path):
