@@ -72,13 +72,13 @@ class File(object):
         r = self._get(absolutePath)
         r.encoding = 'utf-8'
         return r.text
-    def get_csv_wrapper(self, absolutePath):
+    def get_csv_wrapper(self, absolutePath, encoding='utf-8'):
         content = self.get_content(absolutePath)
-        csvWrapper = CsvWrapper(content=content)
+        csvWrapper = CsvWrapper(content=content, encoding=encoding)
         return csvWrapper
-    def get_json_wrapper(self, absolutePath):
+    def get_json_wrapper(self, absolutePath, encoding='utf-8'):
         content = self.get_content(absolutePath)
-        jsonWrapper = JsonWrapper(content=content)
+        jsonWrapper = JsonWrapper(content=content, encoding=encoding)
         return jsonWrapper
     def get_image_wrapper(self, absolutePath):
         content = self.get_content(absolutePath)
